# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [UNRELEASED]

## [0.11.0] - 2025-12-06
### Added
- add support for python 3.14

## [0.10.0] - 2024-10-11
### Added
- add support for python 3.13

## [0.9.0] - 2023-10-07
### Added
- add support for python 3.12

## [0.8.0] - 2023-04-01
### Added

- Add checks for using `fields = "__all__"` or `exclude` in `Meta` class of django model form, DRF model
serializers and django-filter filtersets
- Add tests
